#ifndef WRITE_H
#define WRITE_H


#include <iostream>
#include <fstream>
#include <string>
#include <vector>
#include <map>

#include "io_element_control.h"
#include "graphic.h"
#include "vehicle.h"
#include "telemetry_string.h"

extern string page_string[4];

class Configuration {

   public :
   	Configuration() ;
   	~Configuration() ;
   	int writing(IOElementControl& element, string filename) ;
   	int reading(IOElementControl& element, string filename) ;
   	

   	
};

#endif
