#ifndef DEPTH_H
#define DEPTH_H


#include <iostream>
#include <string>
#include <stdio.h>
#include <pthread.h>
#include <stdlib.h>
#include <unistd.h>
#include "errors.h"

#define MAXCOUNT1	100	
#define MAXCOUNT2	50
#define MAXCOUNT3	25

extern void* depth_head_routine(void* args);
extern int telemetry_status;
extern int receiving_data_counter;

class Tel_Depth {

   public :

   	Tel_Depth();
   	~Tel_Depth();
   	
   	void update_depth_hist(int which_array);
	void update_head_hist();
   	bool get_depth_hist(int which_array, char hist[]);
   	bool get_head_hist(char hist[]);
   	
   	float array1[MAXCOUNT1];	/* 2 minutes */
	float array2[MAXCOUNT2];	/* 30 minutes */
	float array3[MAXCOUNT3];	/* 120 minutes */
	float headArray[MAXCOUNT2];	/* 50 headings hist */	

	int count1;
	int count2;
	int count3;
	int headCount;
	
};

extern Tel_Depth td;			// global object

#endif
