#ifndef __OVERLAY_DEVICE_H
#define __OVERLAY_DEVICE_H




#include "../serial_device.h"
#include "../telemetry_string.h"	
//#include "../vehicle.h"

class OverlayDevice : public SerialDevice {
public:
	OverlayDevice(char* devName, int freq, int type);

	virtual bool parse();
	virtual void setSystemData();
	virtual int send();
	virtual ~OverlayDevice();
private:
	char 	overlayBuf[100];
	
	// copy of the current device is prohibited
        OverlayDevice& operator=(const OverlayDevice& rhs);
        OverlayDevice(const OverlayDevice& rhs);
};


#endif
