/****************************************************************************/
/* Copyright 2008 MBARI.                                                    */
/* MBARI Proprietary Information. All rights reserved.                      */
/****************************************************************************/

#ifndef AUTO_ROV_H
#define AUTO_ROV_H

extern int connectAutoRov(char* name, int port);

extern void disconnectAutoRov();

extern int setAutoRovTimeOut(int timeout);

extern void getAutoRovSrv(char* result);

extern int getAutoRovPort();

extern int getAutoRovConnect();

extern int sendAutoRovCmd(char* cmd, char* resp);

#endif
