#ifndef __SHIPHEAD_DEVICE_H
#define __SHIPHEAD_DEVICE_H



#include "../serial_device.h"
#include "../telemetry_string.h"	

class ShipheadDevice : public SerialDevice {
public:
	ShipheadDevice(char* devName, int period, int type);
	virtual bool parse();
	virtual void setSystemData();
	virtual int send();
	virtual ~ShipheadDevice();
private:
	// copy of the current device is prohibited
        ShipheadDevice& operator=(const ShipheadDevice& rhs);
        ShipheadDevice(const ShipheadDevice& rhs);
	char txbuffer[256];	
	char rxbuffer[255];
};


#endif
