#####################################################
# Create the menu for the "Tool" button                                     #
#####################################################

#--------------
# initially
#--------------
#set tool1 1
#set tool3 1

proc create_tool_submenu { } {
   global tool

   set tool_win .ventana.bar.tool.menu
   menu $tool_win

   #--------------------------------------------#
   # Initially tool is tool 5 -> None	  	#
   #--------------------------------------------#

   set tool tool5
   tool_select 5

   #--------------------------------------------#
   # Create submenu for "Tool"			#
   #--------------------------------------------#

   $tool_win add radio -label "Stbd Drawer" \
 	-variable tool -value tool1 -command {tool_select 1; loop_tool_select_timeout 1}
   $tool_win add separator
   $tool_win add radio -label "Port Swing Arm" \
 	-variable tool -value tool2 -command {tool_select 2; loop_tool_select_timeout 1}
   $tool_win add separator

   $tool_win add radio -label "VB Flood (Dn Close)" \
 	-variable tool -value tool3 -command {tool_select 3; loop_tool_select_timeout 1}
   $tool_win add separator

   $tool_win add radio -label "Port Drawer" \
 	-variable tool -value tool4 -command {tool_select 4; loop_tool_select_timeout 1}
   $tool_win add separator

   $tool_win add radio -label "None" \
 	-variable tool -value tool5 -command {tool_select 5; loop_tool_select_timeout 0}
   $tool_win add separator

}