#ifndef __TMS_DEVICE_H
#define __TMS_DEVICE_H




#include "../serial_device.h"
#include "../telemetry_string.h"	

class TmsDevice : public SerialDevice {
public:
	TmsDevice(char* devName, int freq, int type);
	virtual bool parse();
	virtual void setSystemData();
	virtual int send();
	virtual ~TmsDevice();
private:
	// copy of the current device is prohibited
        TmsDevice& operator=(const TmsDevice& rhs);
        TmsDevice(const TmsDevice& rhs);
	char cab_out[10];
	char cab_speed[10];
	char tension[10];
	char pressure[10];


	char	rxbuffer[256];	

};


#endif
