/************************************************************************
 * 			DTEC Ltd					*
 *			Ventana System					*
 * FILE: 	commands.h						*
 * Description: description added later					*
 * Date:	Sept. 2001						*
 * Authors:	Kenny Huang / Ratna Theresiawati  *
 ************************************************************************/
/* prototypes for functions in commands.c */



/********************************************************************************
*
* this will send command to reboot bottom software and
* start dos com program on the bottom.
* It will stop all traffic transmission except for the software
*
********************************************************************************/	
		   	   	
extern int download_init_cmd (ClientData clientData, Tcl_Interp *interp,
	   	   	int argc, char *argv[]);
	   	   	
	   	
	   	   	
/******************** System Status and Error Counter ****************************/
 	                         	
extern int check_bypass_status_cmd (ClientData clientData, Tcl_Interp *interp,
		   	  	int argc, char *argv[]);
extern int get_telemetry_status_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
extern int bad_packet_counter_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
		

/******************** functions for openGL ****************************/

extern int Lateral_Cmd ( struct Togl *togl, int argc, char *argv[] ) ;
extern int Port_Cmd ( struct Togl *togl, int argc, char *argv[] ) ;
extern int Stbd_Cmd ( struct Togl *togl, int argc, char *argv[] ) ;
extern int Camh1_Cmd ( struct Togl *togl, int argc, char *argv[] ) ;
extern int Camv1_Cmd ( struct Togl *togl, int argc, char *argv[] ) ;
extern int Camh2_Cmd ( struct Togl *togl, int argc, char *argv[] ) ;
extern int Camv2_Cmd ( struct Togl *togl, int argc, char *argv[] ) ;
extern int Roll_Cmd ( struct Togl *togl, int argc, char *argv[] ) ;
extern int Pitch_Cmd ( struct Togl *togl, int argc, char *argv[] ) ;
extern int Vertical_Cmd ( struct Togl *togl, int argc, char *argv[] ) ;


/***************** Tcl/Tk Graphics ***************************************/


extern int get_graph_info_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int set_graphic_info_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				
extern int get_xy_pos_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
			
//----------- light --------------------
				 	              			
extern int get_light_string_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int set_light_db_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				
extern int set_light_conn_db_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
		   	   		
extern int get_light_conn_db_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
				

extern int send_switches_down_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
		   	   	
		   	   	
//------------ compass ------------------

extern int get_compass_string_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_compass_info_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int set_compass_deviation_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_compass_deviation_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_ship_head_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);


				
//----------- vehicle -------------------


extern int get_vehicle_act_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				
extern int get_vehicle_string_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
             				 		
extern int get_vehicle_info_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
	
extern int get_sit_camera_angle_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
		   	   		
extern int get_sony_camera_angle_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_sony_camera_display_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
		   	   	
extern int get_pitch_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_roll_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int set_rpm_interval_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
extern int get_rpm_interval_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_rpm_speed_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
   		   	   			   	   	

//------------- bar graph ---------------
				
extern int setting_bar_detail_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int getting_bar_detail_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_bar_voltage_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
		
extern int retSubAnaSize_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
	


//------------- overlay ---------------

extern int get_ov_count_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_overlay_info_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_overlay_channel_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_overlay_string_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
                                                          		   	   	
extern int get_overlay_string_plus_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int set_dive_num_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_dive_num_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int set_latitude_val_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_latitude_val_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_current_time_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_auto_cruise_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int make_O_item_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
	
extern int delete_O_item_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);



		   	   	
//------------- tms ---------------

extern int get_tms_display_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
 		   	   		
extern int set_tms_display_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_tms_info_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_tms_status_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
		   	   	


				
/******************** functions for io_elements ****************************/


//-------------- Initialization -----------------------


extern int stop_poll_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
		   	  	
extern int subout_make_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
			

//---------------- IO Element Functions ----------------

		   	   	
extern int get_element_name_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
	
extern int clean_up_screen_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int send_io_elem_info_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int ret_all_info_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int ret_io_elem_value_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				
extern int enabling_channel_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);	
				
extern int database_dump_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
			
extern int auto_calibrate_max_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int auto_calibrate_min_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int delete_single_input_cmd (ClientData clientData, Tcl_Interp *interp,
	   	   	int argc, char *argv[]);

extern int send_default_down_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
                                                         	   	   	
extern int get_digital_status_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
		   	   	
extern int get_io_connection_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
		   	   			   	   	
extern int retAnaOutSize_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
		   	   	
//------------- For displaying "list all element" purposes ------------
                                	   	   	
extern int get_analog_value_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
extern int get_top_analog_value_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
extern int get_raw_analog_value_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
extern int get_digital_value_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
	   	   	
extern	int get_sub_output_cmd (ClientData clientData, Tcl_Interp *interp,
	   	   	int argc, char *argv[]);

		   	   	
		   	   	

/***************** configuration files manipulation *********************/

extern int saving_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int opening_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);





/***************** Depth commands *******************************/


extern int get_depth_hist_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_depth_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_auto_depth_status_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);	

extern int get_depth_value_status_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);	

extern int get_auto_depth_setpt_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);	

extern int get_raw_depth_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_depth_graph_info_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
                                                        				

/**************** Altitude commands *****************************/

extern int get_altitude_setpt_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);	

		   	
extern int get_auto_altitude_status_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);	

extern int get_auto_altitude_setpt_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);	

extern int get_altitude_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

		   	   	

/**************** Heading commands *****************************/

extern int get_head_hist_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_head_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_auto_head_status_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
                                                        		   	   	
extern int get_aux_heading_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_dvl_heading_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

		   	   	
/***************** Output ***************************************/

extern int send_out_list_info_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);


extern int display_output_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				
extern int check_out_db_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);	

				


/***************** Button ***************************************/

extern int add_to_button_db_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);	

extern int remove_button_from_db_cmd (ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);	

extern int send_alternate_but_down_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int send_momentary_but_down_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_button_state_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_button_count_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_button_string_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_button_name_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_button_color_type_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				
extern int set_button_state_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_button_connection_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				
extern int get_button_pos_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_bname_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				
extern int get_bcount_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);


/***************** Slidebar *************************************/                                         				 				

extern int add_to_slidebar_db_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);	

extern int remove_slidebar_from_db_cmd (ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);	
				                                         			
extern int send_slide_down_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int set_slide_value_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_slide_value_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				
extern int get_slidebar_string_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_slidebar_name_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_slidebar_count_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_slide_connection_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_slidebar_pos_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_sname_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				
extern int get_scount_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);


/***************** Alarm ***************************************/

extern int check_ana_status_cmd (ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				
extern int check_dig_status_cmd (ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int check_other_status_cmd (ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
			
extern int get_ana_alarm_name_cmd (ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]); 		
			
extern int get_dig_alarm_name_cmd (ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);   	
			
extern int get_other_alarm_name_cmd (ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);    		 	
			
extern int get_alarm_descr_cmd (ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);				
				
extern int get_alarm_name_cmd (ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
					
extern int set_ana_alarm_cmd (ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				
extern int set_other_alarm_cmd (ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
					
extern int clear_alarm_list_cmd (ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
					
extern int send_clear_list_to_bottom_cmd (ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int add_alarm_to_db_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int check_alarm_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int reset_alarm_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int generate_alarm_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);


	
				
/***************** Ground Fault ***************************************/
				

extern int get_8_ground_value_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
extern int select_ground_mode_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
extern int get_16_ground_value_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

				
				 	
/************************ Control ****************************/

//------- Auto Pilot ----------------


extern int saving_auto_pilot_string_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int loading_auto_pilot_string_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				
extern int get_auto_setpt_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
			
extern int set_autopilot_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
	
extern int manipulate_auto_cruise_setpt_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int manipulate_auto_cruise_lat_setpt_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
		   	   	
extern int get_vehicle_speed_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int set_auto_cruise_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);		   	   	
   	   	
//--------------- Arm -----------------

extern int saving_arm_string_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
			
extern int loading_arm_string_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				 	
extern int switch_arm_enable_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int set_arm_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);				

extern int ret_arm_string_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_arm_display_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int send_arm_time_constant_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int get_arm_time_constant_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
		   	   	

//---------------- Camera ----------------
				
extern int saving_cam_string_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int loading_cam_string_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);			
				 	
extern int sending_camera_enable_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
				
extern int set_camera_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);				

extern int ret_camera_string_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
		
extern int get_cam_display_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int send_cam_time_constant_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				
extern int get_cam_time_constant_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
								

/********************* teleos commands ****************************/


 	   	
extern int switch_teleos_enable_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);


extern int set_teleos_setup_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);


extern int get_teleos_info_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_teleos_tx_string_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
		   	   	
extern int get_teleos_rx_string_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);		   	   			   	   	

                                                              		
/********************* Disk Logging ****************************/
				 				
				
extern int update_log_variables_cmd (ClientData clientData, Tcl_Interp *interp,
	   	   	int argc, char *argv[]);
	   	   	
extern int set_disk_enable_cmd (ClientData clientData, Tcl_Interp *interp,
	   	   	int argc, char *argv[]);
	
extern int add_log_item_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int delete_log_item_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int display_log_db_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int check_log_db_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_log_count_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_log_info_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
		
extern int get_disk_status_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
		
	

		   	   	
/************************ Detritus & Tool ****************************/


extern int Detritus_select_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int Tool_select_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);	
	
			
		   	   	

/************************ TESTING PURPOSES ****************************/

extern int show_connection_existence_cmd (ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);	
				

extern int generate_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_ssepy_byte_cmd (ClientData clientData, Tcl_Interp *interp,
	   	   	int argc, char *argv[]);
		   	   	
	   	   	
	   	   	
/************************ Thread ****************************/


extern int test_poll_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int spawn_depth_thread_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);

extern int spawn_receive_thread_cmd(ClientData clientData, Tcl_Interp *interp,
				 int argc, char *argv[]);
				
extern int disk_logging_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
					
extern int serial_sensor_thread_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int dvl_altitude_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_teleos_status_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
		   	   	
extern int get_ship_gyro_status_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
 		   	   	
extern int get_page_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int save_page_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_software_statistics_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);

extern int get_dvl_data_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
		   	   	
extern int get_overlay_strings_from_file_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);
		   	   	
extern int put_overlay_strings_to_file_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);		   		   	   	

extern int put_teleos_ethernet_to_telemetry_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);	
		   	   	
extern int get_teleos_tx_ethernet_cmd (ClientData clientData, Tcl_Interp *interp,
		   	   	int argc, char *argv[]);	


//********************************************************************************
// MBARI Station Keeping Commands
//********************************************************************************
extern int connect_auto_rov_cmd(ClientData clientData, 
                                Tcl_Interp *interp, int argc, char *argv[]);

extern int disconnect_auto_rov_cmd(ClientData clientData, 
                                   Tcl_Interp *interp, int argc, char *argv[]);

extern int set_auto_rov_tmout_cmd(ClientData clientData, 
                                  Tcl_Interp *interp, int argc, char *argv[]);

extern int get_auto_rov_serv_cmd(ClientData clientData, 
                                 Tcl_Interp *interp, int argc, char *argv[]);

extern int get_auto_rov_port_cmd(ClientData clientData, 
                                 Tcl_Interp *interp, int argc, char *argv[]);

extern int get_auto_rov_connect_cmd(ClientData clientData, 
                                    Tcl_Interp *interp, int argc, char *argv[]);

extern int send_auto_rov_cmd_cmd(ClientData clientData, 
                                 Tcl_Interp *interp, int argc, char *argv[]);

//***********************End Station Keeping Commands***********************/
