#ifndef __VISION_DEVICE_H
#define __VISION_DEVICE_H




#include "../serial_device.h"
#include "../telemetry_string.h"	

class VisionDevice : public SerialDevice {
public:
	VisionDevice(char* devName, int freq, int type);
	virtual bool parse();
	virtual void setSystemData();
	virtual int send();
	virtual ~VisionDevice();
	char	rxbuffer[500];		
	
private:
	// copy of the current device is prohibited
        VisionDevice& operator=(const VisionDevice& rhs);
        VisionDevice(const VisionDevice& rhs);

};





#endif
