/***********************************************
 * This is a parser specifically for our program
 * that is "safer" than strtok.
 * we avoid the use of static variables
 * used by strtok to make it thread safe
 * *********************************************/

#ifndef __PARSER_H
	#define __PARSER_H

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <pthread.h>

extern int parse(char strToParse[], char delimeter, int tok_ns[], int nbuff, int ntok); 
extern int parse_vision(char strToParse[], char delimeter, int tok_ns[], int nbuff, int ntok);

#endif
