#ifndef __DEPTH_DEVICE_H
#define __DEPTH_DEVICE_H



#include "../serial_device.h"
#include "../telemetry_string.h"	

class DepthDevice : public SerialDevice {
public:
	DepthDevice(char* devName, int period, int type);
	virtual bool parse();
	virtual void setSystemData();
	virtual int send();
	virtual ~DepthDevice();
private:
	// copy of the current device is prohibited
        DepthDevice& operator=(const DepthDevice& rhs);
        DepthDevice(const DepthDevice& rhs);
	char txbuffer[256];	
	char rxbuffer[255];
};


#endif
