/*****************************************************************************
 * FILE:	digital_in.c
 * BASED ON sample program from ICS ADVENT PCI-DIO96 Documentation
 * Description:	This componenet will read the channel based on the
 *		group, port and channel.
 * NOTE:	The control byte written is different for testing
 *		purposes, REMEMBER TO CHANGE IT when delivering the
 *		product. - Kenny
 ****************************************************************************/

#ifndef _DIGITAL_IN_H
	#define _DIGIAL_IN_H


int readDigitalChannel(int group, int port, unsigned char channel);
bool initializePort(int group);
bool writeControlPort(int group);

#endif
