
#include "rovhead_device.h"

extern Telemetry_String telstring; 


RovheadDevice::RovheadDevice(char* devName, int period, int type)
: SerialDevice(devName, period, type) 
{}


RovheadDevice::~RovheadDevice()
{
	// release data???
}


bool
RovheadDevice::parse()
{
	return false;
}


void
RovheadDevice::setSystemData()
{
}


int
RovheadDevice::send()
{
	telstring.updateOutFields(6);		// 6 for rovheadSend
	telstring.lineout(this->handle(), telstring.rovhead_concat());
	sleep(1);	
	return 0;
}


