#####################################################
# Create the menu for the "Detritus" button                               #
#####################################################






proc create_detritus_submenu { } {

   global dm
   set detritus .ventana.bar.detritus.menu
   menu $detritus

   #--------------------------------------------#
   # Initially detritus is detritus 9 -> None  	#
   #--------------------------------------------#

   set dm dm9
   detritus_select 9

   #--------------------------------------------#
   # Create submenu for "Detrius"		#
   #--------------------------------------------#
   $detritus add separator

   $detritus add radio -label "Detritus 1" \
	-variable dm -value dm1 -command { detritus_select 1 }
   $detritus add separator

   $detritus add radio -label "Detritus 2" \
	-variable dm  -value dm2 -command { detritus_select 2 }
   $detritus add separator

   $detritus add radio -label "Detritus 3" \
	-variable dm -value dm3 -command { detritus_select 3 }
   $detritus add separator

   $detritus add radio -label "Detritus 4" \
	-variable dm -value dm4 -command { detritus_select 4 }
   $detritus add separator


   $detritus add radio -label "Detritus 5" \
	-variable dm -value dm5 -command { detritus_select 5 }
   $detritus add separator

   $detritus add radio -label "Detritus 6" \
	-variable dm -value dm6 -command { detritus_select 6 }
   $detritus add separator

   $detritus add radio -label "Detritus 7" \
	-variable dm -value dm7 -command { detritus_select 7 }
   $detritus add separator

   $detritus add radio -label "Detritus 8" \
	-variable dm -value dm8 -command { detritus_select 8 }
   $detritus add separator

   $detritus add radio -label "None" \
	-variable dm -value dm9 -command { detritus_select 9}
   $detritus add separator
   


}
