#include "head.h"
#include <math.h>
#include "vehicle.h"

#include <iostream>
#include <string>
#include <stdio.h>
#include <pthread.h>
#include <stdlib.h>
#include <unistd.h>
#include "errors.h"

/*******************************************************/
//No longer used in Ventana Control Mar 2003
/*******************************************************/

float head_array[50];
extern int deviation_fog;

void *head_routine(void *args)
{
 	while(1)
 	{
 		if (headCount >= 50)
		headCount = 0;
		
		head_array[headCount++] = vehicle.curr_heading + deviation_fog;
 		sleep(1);	
 	}
}