extern float current_zrot;
extern float current_xrot;
extern float move;
extern float accel;
extern float camv1;
extern float camh1;
extern float slide;
extern float base_rad;

extern void do_transformations( void );
extern void cam_transformations( void );
extern void draw_sub ( void );
extern void draw_camera1( void );
extern void draw_horizon( void );
