
#include "shiphead_device.h"

extern Telemetry_String telstring; 


ShipheadDevice::ShipheadDevice(char* devName, int period, int type)
: SerialDevice(devName, period, type) 
{}


ShipheadDevice::~ShipheadDevice()
{
	// release data???
}


bool
ShipheadDevice::parse()
{
	return false;
}


void
ShipheadDevice::setSystemData()
{
}


int
ShipheadDevice::send()
{
	telstring.updateOutFields(7);		// 7 for shipheadSend
	telstring.lineout(this->handle(), telstring.shiphead_concat());
	sleep(1);	
	return 0;
}


