#include "logging_device.h"

extern Telemetry_String telstring; 


LoggingDevice::LoggingDevice(char* devName, int period, int type)
: SerialDevice(devName, period, type) 
{}


LoggingDevice::~LoggingDevice()
{
	// release data???
}


bool
LoggingDevice::parse()
{
	return false;
}


void
LoggingDevice::setSystemData()
{
}


int
LoggingDevice::send()
{
	telstring.updateOutFields(0);		// 0 for logSend
	telstring.lineout(this->handle(), telstring.logging_concat());
	sleep(1);	
	return 0;
}


