extern int rotation_mode;
extern float current_xrot;
extern float current_zrot;
extern float lateral;
extern float port;
extern float stbd;
extern float camv1;
extern float camh1;
extern float camv2;
extern float camh2;
extern float vertical;
extern float base_rad;
extern double matrix_rot [16];
extern double cam_matrix_rot[16];

void do_transformations();
void draw_sub();
void draw_camera1();
void draw_camera2();
