
#include "depth_device.h"

extern Telemetry_String telstring; 


DepthDevice::DepthDevice(char* devName, int period, int type)
: SerialDevice(devName, period, type) 
{}


DepthDevice::~DepthDevice()
{
	// release data???
}


bool
DepthDevice::parse()
{
	return false;
}


void
DepthDevice::setSystemData()
{
}


int
DepthDevice::send()
{
	telstring.updateOutFields(5);		// 5 for depthSend
	telstring.lineout(this->handle(), telstring.depth_concat());
	sleep(1);	
	return 0;
}


