#ifndef __GYRO_DEVICE_H
#define __GYRO_DEVICE_H




#include "../serial_device.h"
#include "../telemetry_string.h"	
#include "../vehicle.h"

class GyroDevice : public SerialDevice {
public:
	GyroDevice(char* devName, int freq, int type);

	virtual bool parse();
	virtual void setSystemData();
	virtual int send();
	virtual ~GyroDevice();
private:
	char 	gyroBuf[100];
	
	bool helper(char* ptr, int nBytes, float* f);
	void	parseHelper(char*, int);

	// copy of the current device is prohibited
        GyroDevice& operator=(const GyroDevice& rhs);
        GyroDevice(const GyroDevice& rhs);
};


#endif
