##############################################################################
# Copyright 2003 MBARI.                                                      #
# Monterey Bay Aquarium Research Institute Proprietary Information.          #
# All rights reserved.                                                       #
##############################################################################

set bearing_input 0.0
set dist_input 10.0

#
# disable commands
#

proc disable_move {} {
	global pilot_interface
	
    $pilot_interface.move_frm.move_btn configure -state disabled

    $pilot_interface.move_frm.bearing_ent configure -state disabled
    $pilot_interface.move_frm.dist_ent configure -state disabled
}

proc enable_move {} {
	global pilot_interface
	
    $pilot_interface.move_frm.move_btn configure -state normal
    $pilot_interface.move_frm.bearing_ent configure -state normal
    $pilot_interface.move_frm.dist_ent configure -state normal
}

#
# move command
#

proc move_cmd {} {  
    global bearing_input dist_input slew_rate
    send_auto_rov_cmd "MOVE $bearing_input, $dist_input, $slew_rate"
}

