#ifndef __LOGGING_DEVICE_H
#define __LOGGING_DEVICE_H



#include "../serial_device.h"
#include "../telemetry_string.h"	

class LoggingDevice : public SerialDevice {
public:
	LoggingDevice(char* devName, int period, int type);
	virtual bool parse();
	virtual void setSystemData();
	virtual int send();
	virtual ~LoggingDevice();
private:
	// copy of the current device is prohibited
        LoggingDevice& operator=(const LoggingDevice& rhs);
        LoggingDevice(const LoggingDevice& rhs);
	char	txbuffer[256];	
	char rxbuffer[255];
};


#endif
