/*******************************************************
 * FILE:	Thruster_curves.h
 * Descp:	This file contains some of the 
 *		helper functions. 
 *		The scale factor for the the deadband
 *		and saturation functions are of inverse
 * 		of each other. 
 *		
 *******************************************************/

float 	nl(float V_l);
float 	nlInverse(float V_l);
float 	initializeLookupTable(float* lookupTable);
int	nearestNeighborSearch(float V_1, float* lookupTable);
float	int2float(int n); 
