# Hide the small main window
wm geometry . 0x0+0+0; update

# Open a file automatically
clean_up_screen
opening "config/ventana.cfg"
destroy .ventana
destroy .ventana2
global env
set env(DISPLAY) :0.1
source test2.tcl
set env(DISPLAY) :0
source test.tcl

#display_all_graphic is in file_proc calls all the stuff below
#	display_button
#	display_slidebar
#  	display_light
#      	display_compass
#      	display_vehicle_graphic
#     	display_bar_and_depth
#      	display_camera_values      	
#      	display_arm_values      	
#      	display_auto_pilot_values
#       display_tms
#       display_tms2

display_all_graphic

# Run the ethernet loop to communicate with the vision system
#sensor7_ethernet

# Run the loop to check telemetry status and alarm
alarm
test_poll
spawn_receive_thread
spawn_depth_thread
serial_sensor_thread


# This thread will start the logging to disk or printer
# This logging thread is not the same as the logging thread above
# because this thread will actually have logging fields that the user
# can customize through the GUI
disk_logging



