#ifndef __ROVHEAD_DEVICE_H
#define __ROVHEAD_DEVICE_H



#include "../serial_device.h"
#include "../telemetry_string.h"	

class RovheadDevice : public SerialDevice {
public:
	RovheadDevice(char* devName, int period, int type);
	virtual bool parse();
	virtual void setSystemData();
	virtual int send();
	virtual ~RovheadDevice();
private:
	// copy of the current device is prohibited
        RovheadDevice& operator=(const RovheadDevice& rhs);
        RovheadDevice(const RovheadDevice& rhs);
	char txbuffer[256];	
	char rxbuffer[255];
};


#endif
