/*********************************************************************
 * CRC calculaton
 * we use the CCITT standard
 * 			CCITT		CRC16		CRC32
 * 			16 bits		16 bits		32 bits
 * Divisor		0x1021		0x8005		0x04C11DB7	
 * Initial remainder	0xFFFF		0x0000		0xFFFFFFFF
 * Final XOR Value 	0x0000		0x0000		0xFFFFFFFF
 *******************************************************************/
#ifndef __CRC_H__
	#define +__CRC_H_
#define WIDTH 	(8*sizeof(width))

void crcInit(void);
width crcCompute(unsigned char* message, unsigned int nBytes);

#endif